<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Presenter;
use Illuminate\Http\Request;
use Sabberworm\CSS\Rule\Rule;

class AdminPresenterController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        return view('admin.presenters.index',['presenters'=>Presenter::all()]);
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('admin.presenters.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $request->validate([
            'name'=>['required','unique:presenters,name'],
            'image'=>['required','mimes:png,jpg'],
            'label'=>['required'],
            'sort'=>['required']
        ]);
        $path = $request->file('image')->storeAs('public/images/presenters',$request->file('image')->getClientOriginalName());
        Presenter::query()->create([
            'name'=>$request->name,
            'image'=>$path,
            'label'=>$request->label,
            'sort'=>$request->sort,
            'status'=>$request->status == 1 ? 1 : 0,
        ]);
        toast('با موفقیت ایجاد شد','success');
        return redirect(route('presenters.index'));
    }

    /**
     * Display the specified resource.
     */
    public function show(Presenter $presenter)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(Presenter $presenter)
    {
        return view('admin.presenters.edit',['presenter'=>$presenter]);
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, Presenter $presenter)
    {
        $request->validate([
            'name'=>['required',\Illuminate\Validation\Rule::unique('presenters')->ignore($presenter)],
            'image'=>['mimes:png,jpg'],
            'label'=>['required'],
            'sort'=>['required']
        ]);
        $path = $presenter->image;
        if ($request->hasFile('image')){
            $path = $request->file('image')->storeAs('public/images/presenters',$request->file('image')->getClientOriginalName());
        }

        $presenter->update([
            'name'=>$request->get('name',$presenter->name),
            'image'=>$path,
            'label'=>$request->get('label',$presenter->label),
            'sort'=>$request->get('sort',$presenter->sort),
            'status'=>$request->status == 1 ? 1 : 0,
        ]);
        toast('با موفقیت ویرایش شد','success');
        return redirect(route('presenters.index'));
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Presenter $presenter)
    {
        //
    }
}
