<?php

namespace App\Http\Controllers\Admin;

use App\Exports\Card;
use App\Exports\ClassSym;
use App\Exports\ExportAssistant;
use App\Exports\ExportRegister;
use App\Exports\NotExists;
use App\Exports\Tel;
use App\Http\Controllers\Controller;
use App\Models\Register;
use App\Models\Type;
use App\Models\User;
use App\Rules\NationalCode;
use App\Sms\Sms;
use Illuminate\Http\Request;
use Illuminate\Validation\Rule;
use Maatwebsite\Excel\Facades\Excel;
use Shetabit\Payment\Facade\Payment;
use Shetabit\Multipay\Exceptions\InvalidPaymentException;
class AdminRegisterClientController extends Controller
{
    public function index()
    {
        $assistantId = Type::query()->where('title','=','دستیار')->first();
        if (auth()->user()->role_id == 2){
            return view('admin.clientRegister.index',['users'=>Register::query()->whereNot('type_id',$assistantId->id)->whereNot('status','=',3)->get()]);
        }elseif (auth()->user()->role_id == 3 ){
            return view('admin.clientRegister.index',['users'=>Register::query()->whereNot('type_id',$assistantId->id)->whereNot('status','=',3)->where('city_id',auth()->user()->city_id)->get()]);
        }
        else{
            return view('admin.clientRegister.index',['users'=>Register::query()->whereNot('type_id',$assistantId->id)->whereNot('status','=',3)->where('user_id',auth()->id())->get()]);
        }
    }

    public function assistant_index()
    {
        $assistantId = Type::query()->where('title','=','دستیار')->first();
        if (auth()->user()->role_id == 2 ){
            return view('admin.clientRegister.assistant_index',['users'=>Register::query()->where('type_id',$assistantId->id)->whereNot('status','=',3)->get()]);
        }elseif(auth()->user()->role_id == 3 ) {
            return view('admin.clientRegister.assistant_index',['users'=>Register::query()->where('type_id',$assistantId->id)->whereNot('status','=',3)->where('city_id',auth()->user()->city_id)->get()]);
        }
        else {
            return view('admin.clientRegister.assistant_index',['users'=>Register::query()->where('type_id',$assistantId->id)->whereNot('status','=',3)->where('user_id',auth()->id())->get()]);
        }
    }

    public function create_client(User $user)
    {
        return view('admin.clientRegister.create',['user'=>$user]);
    }

    public function create_assistant(User $user)
    {
        return view('admin.clientRegister.create_assistant',['user'=>$user]);
    }

    public function store_client(Request $request,User $user)
    {
        $request->validate([
            'fullName_fa'=>['required'],
            'fullName_en'=>['required'],
            'mobile'=>['required','unique:registers,mobile'],
            'nationalCode'=>['required',new NationalCode,'unique:registers,nationalCode' ],
            'type_id'=>['required' ],
            'expert_id'=>['required' ],
        ]);

        $transactionId = '';
        $status_pay = 0;
        if ($request->transactionId){
            $transactionId = $request->transactionId;
            $status_pay = 1;
        }
        $client_register = \App\Models\Register::query()->create([
            'fullName_fa'=>$request->fullName_fa,
            'fullName_en'=>$request->fullName_en,
            'mobile'=>$request->mobile,
            'nationalCode'=>$request->nationalCode,
            'type_id'=>$request->type_id,
            'expert_id'=>$request->expert_id,
            'city_id'=>$user->city_id,
            'club'=>$request->club == 1 ? 1 : 0,
            'dionavi'=>$request->dionavi == 1 ? 1 : 0,
            'user_id'=>$user->id,
            'customerCode'=>$request->customerCode,
            'nezamCode'=>$request->nezamCode
        ]);

        if ($request->assistant_name && $request->assistant_mobile && $request->assistant_nationalCode && $client_register->id ){

            $request->validate([
                'fullName_fa'=>['required'],
                'mobile'=>['required','unique:registers,mobile'],
                'nationalCode'=>['required',new NationalCode,'unique:registers,nationalCode' ],
            ]);

            $assistant = \App\Models\Register::query()->create([
                'fullName_fa'=>$request->assistant_name,
                'mobile'=>$request->assistant_mobile,
                'nationalCode'=>$request->assistant_nationalCode,
                'register_id'=>$client_register->id,
                'city_id'=>User::query()->where('id',$request->user_id)->first()->city->id,
                'type_id'=>7,
                'user_id'=>$user->id,
            ]);
        }
        toast('با موفقیت ثبت شد','success');
        return redirect(route('client.register'));
    }


    public function store_assistant(Request $request,User $user)
    {

        $request->validate([
            'fullName_fa'=>['required'],
            'mobile'=>['required','unique:registers,mobile'],
            'nationalCode'=>['required',new NationalCode,'unique:registers,nationalCode' ],
        ]);

        $assistant = \App\Models\Register::query()->create([
            'fullName_fa'=>$request->fullName_fa,
            'fullName_en'=>$request->fullName_en,
            'mobile'=>$request->mobile,
            'nationalCode'=>$request->nationalCode,
            'register_id'=>$request->register_id,
            'city_id'=>User::query()->where('id',$request->user_id)->first()->city->id,
            'type_id'=>7,
            'user_id'=>$request->user_id,
        ]);
        toast('با موفقیت ثبت شد','success');
        return redirect(route('client.register.assistant'));
    }

    public function edit_client(Register $register,User $user)
    {

        if ($register->type_id != 7 ){
            return view('admin.clientRegister.edit',['register'=>$register,'user'=>$user]);
        }else{

            return  view('admin.clientRegister.edit_assistant',['register'=>$register,'user'=>$user]);
        }

    }

    public function update_client(Request $request,Register $register,User $user)
    {

        $request->validate([
            'fullName_fa'=>['required'],
            'fullName_en'=>['required'],
            'mobile'=>['required',Rule::unique('registers')->ignore($register)],
            'nationalCode'=>['required',new NationalCode,Rule::unique('registers')->ignore($register) ],
            'type_id'=>['required' ],
            'expert_id'=>['required' ],
        ]);

        $invoice = '';
        $status_pay = '';
        if ($request->invoice){
            $invoice = $request->invoice;
            $status_pay = 'OK';
        }

        $register->update([
            'fullName_fa'=>$request->get('fullName_fa',$register->fullName_fa),
            'fullName_en'=>$request->get('fullName_en',$register->fullName_en),
            'mobile'=>$request->mobile,
            'nationalCode'=>$request->get('nationalCode',$register->nationalCode),
            'type_id'=>$request->get('type_id',$register->type_id),
            'expert_id'=>$request->get('expert_id',$register->expert_id),
            'club'=>$request->club == 1 ? 1 : 0,
            'dionavi'=>$request->dionavi == 1 ? 1 : 0,
            'invoice'=>$invoice,
            'status_pay'=>$status_pay,
            'user_id'=>$request->user_id,
            'city_id'=>$request->get('city_id',$register->city_id),
            'status'=>$request->status,
            'customerCode'=>$request->get('customerCode',$register->customerCode),
            'nezamCode'=>$request->nezamCode
        ]);

        toast('با موفقیت ویرایش شد','success');
        return redirect(route('client.register'));
    }


    public function update_assistant(Request $request,Register $register,User $user)
    {
        $request->validate([
            'fullName_fa'=>['required'],
            'mobile'=>['required',Rule::unique('registers')->ignore($register)],
            'nationalCode'=>['required',new NationalCode,Rule::unique('registers')->ignore($register) ],
        ]);

        $invoice = '';
        $status_pay = '';
        if ($request->invoice){
            $invoice = $request->invoice;
            $status_pay = 'OK';
        }

        $register->update([
            'fullName_fa'=>$request->get('fullName_fa',$register->fullName_fa),
            'fullName_en'=>$request->get('fullName_en',$register->fullName_en),
            'mobile'=>$request->mobile,
            'nationalCode'=>$request->get('nationalCode',$register->nationalCode),
            'invoice'=>$invoice,
            'status_pay'=>$status_pay,
            'user_id'=>$request->get('user_id',$register->user_id),
            'city_id'=>User::query()->where('id',$request->user_id)->first()->city->id,
            'status'=>$request->status,
            'register_id'=>$request->get('register_id',$register->register_id)
        ]);

        toast('با موفقیت ویرایش شد','success');
        return redirect(route('client.register.assistant'));
    }

    public function check($transaction,$price)
    {
        try {
            $receipt = Payment::amount($price)->transactionId($transaction)->verify();

            // You can show payment referenceId to the user.
            echo $receipt->getReferenceId();
            echo 'موفق';
        } catch (InvalidPaymentException $exception) {
            /**
            when payment is not verified, it will throw an exception.
            We can catch the exception to handle invalid payments.
            getMessage method, returns a suitable message that can be used in user interface.
             **/
            echo $exception->getMessage();
        }
    }

    public function export()
    {
        return Excel::download(new ExportRegister, 'users.xlsx');
    }
    public function cards()
    {
        return Excel::download(new Card, 'cards.xlsx');
    }
    public function class()
    {
        return Excel::download(new ClassSym, 'class.xlsx');
    }

    public function tel()
    {
        return Excel::download(new Tel, 'tel.xlsx');
    }

    public function notExists()
    {
        return Excel::download(new NotExists, 'notExists.xlsx');
    }


    public function export_assistant()
    {
        return Excel::download(new ExportAssistant, 'users.xlsx');
    }

    public function notif(Request $request,Register $register)
    {

        $register->update([
            'notif'=>$request->notif
        ]);
        return back();
    }


    public function index_cancel()
    {
        $assistantId = Type::query()->where('title','=','دستیار')->first();
        if (auth()->user()->role_id == 2){
            return view('admin.clientRegister.index_cancel',['users'=>Register::query()->whereNot('type_id',$assistantId->id)->where('status','=',3)->get()]);
        }elseif (auth()->user()->role_id == 3 ){
            return view('admin.clientRegister.index',['users'=>Register::query()->whereNot('type_id',$assistantId->id)->where('status','=',3)->where('city_id',auth()->user()->city_id)->get()]);
        }
        else{
            return view('admin.clientRegister.index',['users'=>Register::query()->whereNot('type_id',$assistantId->id)->where('user_id',auth()->id())->where('status','=',3)->get()]);
        }
    }

    public function assistant_index_cancel()
    {
        $assistantId = Type::query()->where('title','=','دستیار')->first();
        if (auth()->user()->role_id == 2 ){
            return view('admin.clientRegister.assistant_index',['users'=>Register::query()->where('type_id',$assistantId->id)->where('status','=',3)->get()]);
        }elseif(auth()->user()->role_id == 3 ) {
            return view('admin.clientRegister.assistant_index',['users'=>Register::query()->where('type_id',$assistantId->id)->where('status','=',3)->where('city_id',auth()->user()->city_id)->get()]);
        }
        else {
            return view('admin.clientRegister.assistant_index',['users'=>Register::query()->where('type_id',$assistantId->id)->where('status','=',3)->where('user_id',auth()->id())->get()]);
        }
    }

}
