<?php

namespace App\Http\Controllers;

use App\Models\ClubCode;
use App\Models\ClubDionavi;
use App\Models\Register;
use App\Models\User;
use App\Rules\NationalCode;
use App\Sms\Sms;
use Illuminate\Http\Request;
use RealRashid\SweetAlert\Facades\Alert;
use Shetabit\Multipay\Invoice;
use Shetabit\Payment\Facade\Payment;

class RegisterController extends Controller
{
    public function index(Request $request)
    {
        $register_exists = Register::query()->where('nationalCode',$request->nationalCode)->first();
        if ($register_exists){
            Alert::warning('با این کد ملی قبلا ثبت نام انجام شده است');
            return back();
        }else{
            $data = $request->validate([
                'fullName_fa'=>['required'],
                'fullName_en'=>['required',],
                'mobile'=>['required','unique:registers,mobile','digits:11','regex:/(09)[0-9]{9}/'],
                'nationalCode'=>['required','unique:registers,nationalCode',new NationalCode],
                'type_id'=>['required','exists:types,id'],
                'expert_id'=>['required','exists:experts,id'],
                'city_id'=>['required','exists:cities,id']
            ]);
            $register =  Register::query()->create($data);
            $invoice = (new Invoice)->amount(4740000);
            return Payment::purchase($invoice, function($driver, $transactionId) use ($register) {
                $register->update([
                    'transactionId'=>$transactionId
                ]);
            })->pay()->render();
        }
    }

    public function callback(Request $request)
    {
        $register = Register::query()->where('transactionId',$request->Authority)->first();

        if ($request->Status == 'OK'){
            $register->update([
                'status_pay'=>'OK'
            ]);
            $text = $register->fullName_fa." عزیز "."\n    ثبت نام شما در چهارمین سمپوزیوم شرکت دانش بنیان دایو پارس با موفقیت انجام شد."."\nجهت کسب اطلاعات بیشتر با کارشناس فروش ما در ارتباط باشید یا عدد 1 را ارسال نماید.شرکت دانش بنیان دایوپارس."."\n لغو 11";
            Sms::sms($register->mobile,$text);
            toast('پرداخت و ثبت نام با موفقیت انجام شد','success');
            return redirect('/');
        }else{
            //$register->delete();
            $text = $register->fullName_fa." عزیز "."\n    پیش ثبت نام شما در چهارمین سمپوزیوم شرکت دانش بنیان دایو پارس با موفقیت انجام شد."."\nجهت کسب اطلاعات بیشتر و پرداخت هزینه با کارشناس فروش ما در ارتباط باشید یا عدد 1 را ارسال نماید.شرکت دانش بنیان دایوپارس."."\n لغو 11";
            Sms::sms($register->mobile,$text);
            toast('پرداخت و ثبت نام با موفقیت انجام نشد','warning');
            return redirect('/');
        }
    }

    public function invoice(Register $register)
    {
        $club = null;
        $price = 4740000;
        if ($register->club == 1 ){
            $code =  ClubCode::query()->where('dentistCode',$register->nationalCode)->first();
            if ($code){
                $price = 2844000;
                $club = 'شامل تخفیف عضو محترم انجمن فک و دهان و صورت';
            }else{
                $price;
            }
        }elseif ($register->dionavi == 1 ){
            $dionavi = ClubDionavi::query()->where('mobile',$register->mobile)->first();
            if ($dionavi){
                $price = 3792000;
                $club = 'شامل تخفیف عضویت در دیونوی';
            }else{
                $price;
            }
        }elseif ($register->type_id == 4 || $register->type_id == 5 ){
            $price = 3318000;
            $club = 'شامل تخفیف ';
        }elseif ( $register->type_id == 6 ){
            $price = 3792000;
            $club = 'شامل تخفیف ';
        }elseif ($register->type_id == 3 ){
            $price = 4266000;
            $club = 'شامل تخفیف ';
        }

        return view('invoice',['register'=>$register,'club'=>$club,'price'=>$price]);
    }

    public function pay(Register $register,$price)
    {
        $invoice = (new Invoice)->amount($price);

        return Payment::purchase($invoice, function($driver, $transactionId) use ($register,$price) {
            $register->update([
                'transactionId'=>$transactionId,
                'price'=>$price
            ]);
        })->pay()->render();
    }

    public function schedule()
    {

        return response()->file('client/schedule/1.jpg');
    }
}
