<?php

namespace App\Http\Livewire;

use App\Models\Upload;
use App\Rules\NationalCode;
use Livewire\Component;
use Livewire\WithFileUploads;
use Shetabit\Multipay\Invoice;
use Shetabit\Payment\Facade\Payment;

class Register extends Component
{

    use WithFileUploads;
    public $state =
        [
            'type_id'=>'',
            'expert_id'=>'',
            'fullName_fa'=>'',
            'fullName_en'=>'',
            'nationalCode'=>'',
            'mobile'=>'',
            'city_id'=>'',
            'status'=>'',
            'assistant_name'=>'',
            'assistant_nationalCode'=>'',
            'assistant_mobile'=>'',
            'all_status'=>'',
            'club'=>'',
            'dionavi'=>'',
        ];

    public $type_id;
    public $expert_id;
    public $fullName_fa;
    public $fullName_en;
    public $nationalCode;
    public $mobile;
    public $city_id;
    public $assistant_name;
    public $assistant_nationalCode;
    public $assistant_mobile;
    public $image;

    public function rules()
    {
        return [
            'type_id'=>['exists:types,id'],
            'expert_id'=>['exists:experts,id'],
            'fullName_fa'=>['required'],
            'fullName_en'=>['required'],
            'nationalCode'=>[new NationalCode ,'unique:registers,nationalCode'],
            'mobile'=>['required','unique:registers,mobile','digits:11','regex:/(09)[0-9]{9}/'],
            'city_id'=>['required'],
        ];
    }


    public function updatedStateCityId()
    {
        $this->type_id = $this->state['type_id'];
        $this->expert_id = $this->state['expert_id'];
        $this->fullName_fa = $this->state['fullName_fa'];
        $this->fullName_en = $this->state['fullName_en'];
        $this->nationalCode = $this->state['nationalCode'];
        $this->mobile = $this->state['mobile'];
        $this->city_id = $this->state['city_id'];
        $this->validate();
        $this->state['status'] = 1 ;
    }

    public function updatedStateAssistantMobile()
    {
        $this->assistant_name = $this->state['assistant_name'];
        $this->assistant_nationalCode = $this->state['assistant_nationalCode'];
        $this->assistant_mobile = $this->state['assistant_mobile'];
        $this->validate([
            'assistant_name'=>['required'],
            'assistant_nationalCode'=>[new NationalCode , 'unique:registers,nationalCode'],
            'assistant_mobile'=>['required','unique:registers,mobile','digits:11','regex:/(09)[0-9]{9}/']
        ]);
        $this->state['all_status'] = 1;
    }

    public function updatedImage ()
    {
        $this->validate([
            'image' => 'image|max:1024000',
        ]);

    }

    public function register()
    {
        if ($this->state['type_id'] == 3 || $this->state['type_id'] == 4 || $this->state['type_id'] == 5 || $this->state['type_id'] == 6 )
        {
            $client_register = \App\Models\Register::query()->create([
                'fullName_fa'=>$this->fullName_fa,
                'fullName_en'=>$this->fullName_en,
                'mobile'=>$this->mobile,
                'nationalCode'=>$this->nationalCode,
                'type_id'=>$this->type_id,
                'expert_id'=>$this->expert_id,
                'city_id'=>$this->city_id,
            ]);
           Upload::query()->create([
               'register_id'=>$client_register->id,
               'image'=>$this->image->storeAs('public/images/upload',$client_register->id.'.jpg')
           ]);
            toast('ثبت نام با موفقیت انجام شد','success');
            return redirect(route('invoice',$client_register));

        }else{
            $client_register = \App\Models\Register::query()->create([
                'fullName_fa'=>$this->fullName_fa,
                'fullName_en'=>$this->fullName_en,
                'mobile'=>$this->mobile,
                'nationalCode'=>$this->nationalCode,
                'type_id'=>$this->type_id,
                'expert_id'=>$this->expert_id,
                'city_id'=>$this->city_id,
                'club'=>$this->state['club'] == 1 ? 1 : 0,
                'dionavi'=>$this->state['dionavi'] == 1 ? 1 : 0,
            ]);

            if ($this->state['all_status'] == 1 ){
                $assistant = \App\Models\Register::query()->create([
                    'fullName_fa'=>$this->assistant_name,
                    'mobile'=>$this->assistant_mobile,
                    'nationalCode'=>$this->assistant_nationalCode,
                    'register_id'=>$client_register->id,
                    'city_id'=>$this->city_id,
                    'type_id'=>7
                ]);
            }


            toast('ثبت نام با موفقیت انجام شد','success');
            return redirect(route('invoice',$client_register));

        }



    }


    public function render()
    {
        return view('livewire.register');
    }
}
