<?php

use App\Http\Controllers\Admin\AdminCardController;
use App\Http\Controllers\Admin\AdminCityController;
use App\Http\Controllers\Admin\AdminClubCodeController;
use App\Http\Controllers\Admin\AdminClubDionaviController;
use App\Http\Controllers\Admin\AdminExpertController;
use App\Http\Controllers\Admin\AdminHomeController;
use App\Http\Controllers\Admin\AdminPermissionController;
use App\Http\Controllers\Admin\AdminQuestionController;
use App\Http\Controllers\Admin\AdminRegisterClientController;
use App\Http\Controllers\Admin\AdminRoleController;
use App\Http\Controllers\Admin\AdminSymposiumNorthAmericanController;
use App\Http\Controllers\Admin\AdminTypeController;
use App\Http\Controllers\Admin\AdminUserController;
use App\Http\Controllers\Auth\AdminAuthController;
use App\Http\Controllers\Client\ClientRegisterSymposiumNorth;
use App\Http\Controllers\RegisterController;
use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "web" middleware group. Make something great!
|
*/

Route::get('/', function () {
    //dd(bcrypt('PerDio@123'));
    return view('welcome_2');
});
Route::post('register',[RegisterController::class,'index'])->name('register');
Route::get('invoice/{register}',[RegisterController::class,'invoice'])->name('invoice');
Route::get('pay/invoice/{register}/{price}',[RegisterController::class,'pay'])->name('pay.invoice');
Route::get('callback',[RegisterController::class,'callback'])->name('callback');

Route::get('login',[AdminAuthController::class,'index'])->name('login');
Route::post('login/mobile',[AdminAuthController::class,'send_otp'])->name('login.mobile');
Route::get('login/otp/{user}',[AdminAuthController::class,'login_otp'])->name('login.otp');
Route::post('login/otp/{user}/verify',[AdminAuthController::class,'verify'])->name('login.verify');
Route::get('logout/',[AdminAuthController::class,'logout'])->name('logout');

Route::get('/schedule',[RegisterController::class,'schedule'])->name('schedule');

Route::get('/questions',[\App\Http\Controllers\Client\ClientQuestionController::class,'index'])->name('questions');
Route::post('questions/store',[\App\Http\Controllers\Client\ClientQuestionController::class,'store'])->name('questions.store');

Route::post('register/symposium/north',[ClientRegisterSymposiumNorth::class,'register'])->name('register.symposium.north.american');

Route::prefix('admin')->middleware('auth')->group(function (){
    Route::get('home/{user}',[AdminHomeController::class,'index'])->name('admin.home');
    Route::resource('permissions',AdminPermissionController::class);
    Route::resource('roles',AdminRoleController::class);
    Route::resource('users',AdminUserController::class);
    Route::resource('cities',AdminCityController::class);
    Route::resource('experts',AdminExpertController::class);
    Route::resource('types',AdminTypeController::class);
    Route::resource('clubCodes',AdminClubCodeController::class);
    Route::resource('clubDionavis',AdminClubDionaviController::class);
    Route::get('register/clients',[AdminRegisterClientController::class,'index'])->name('client.register');
    Route::get('register/clients/cancel',[AdminRegisterClientController::class,'index_cancel'])->name('client.register.cancel');
    Route::get('register/clients/assistant',[AdminRegisterClientController::class,'assistant_index'])->name('client.register.assistant');
    Route::get('register/clients/assistant/cancel',[AdminRegisterClientController::class,'assistant_index_cancel'])->name('client.register.assistant.cancel');
    Route::get('register/create/client/{user}',[AdminRegisterClientController::class,'create_client'])->name('register.create');
    Route::get('register/create/assistant/{user}',[AdminRegisterClientController::class,'create_assistant'])->name('register.create_assistant');
    Route::post('register/create/store/{user}',[AdminRegisterClientController::class,'store_client'])->name('register.store');
    Route::post('register/create/assistant/store/{user}',[AdminRegisterClientController::class,'store_assistant'])->name('register.store_assistant');
    Route::get('register/edit/{register}/{user}',[AdminRegisterClientController::class,'edit_client'])->name('register.edit');
    Route::post('register/edit/{register}/{user}',[AdminRegisterClientController::class,'update_client'])->name('register.update');
    Route::post('register/edit/{register}/{user}/assistant',[AdminRegisterClientController::class,'update_assistant'])->name('register.update_assistant');

    Route::get('register/check/transaction/{id}/{price}',[AdminRegisterClientController::class,'check'])->name('check.transaction');

    Route::get('register/export',[AdminRegisterClientController::class,'export'])->name('register.export');
    Route::get('register/assistant/export',[AdminRegisterClientController::class,'export_assistant'])->name('register.assistant.export');
    Route::post('register/notif/registers/{register}',[AdminRegisterClientController::class,'notif'])->name('register.notif');

    Route::get('client/registers/cards/{user}',[AdminCardController::class,'index'])->name('client.register.cards');
    Route::get('client/registers/assistant/cards/{user}',[AdminCardController::class,'index_assistant'])->name('client.register.assistant.cards');

    Route::get('cards/symposium/salon/{register}',[AdminCardController::class,'card_register_dentist'])->name('cards.symposium.salon');
    Route::get('cards/symposium/food/{register}',[AdminCardController::class,'food_register_dentist'])->name('cards.symposium.food');

    Route::get('cards/symposium/assistant/salon/{register}',[AdminCardController::class,'card_register_assistant'])->name('cards.symposium.salon.assistant');
    Route::get('cards/symposium/assistant/food/{register}',[AdminCardController::class,'food_register_assistant'])->name('cards.symposium.food.assistant');

    Route::get('enter/index',\App\Http\Livewire\Enter::class)->name('enter.index');

    Route::get('exports/class',[AdminRegisterClientController::class,'class'])->name('exports.class');
    Route::get('exports/cards',[AdminRegisterClientController::class,'cards'])->name('exports.card');
    Route::get('exports/tels',[AdminRegisterClientController::class,'tel'])->name('exports.tel');
    Route::get('exports/notExists',[AdminRegisterClientController::class,'notExists'])->name('exports.notExists');

    Route::resource('presenters',\App\Http\Controllers\Admin\AdminPresenterController::class);

    Route::get('questions/index',[AdminQuestionController::class,'index'])->name('questions.index');
    Route::get('questions/presenter',[AdminQuestionController::class,'question_presenter'])->name('questions.presenter');
    Route::get('questions/presenter/{presenter}',[AdminQuestionController::class,'question_presenter_index'])->name('questions.presenter.present');
    Route::get('questions/presenter/{presenter}/questions/',[AdminQuestionController::class,'show_questions'])->name('questions.presenter.questions');
    Route::get('questions/accept/{question}',[AdminQuestionController::class,'accept'])->name('questions.accept');


    Route::get('symposium_n_a',[AdminSymposiumNorthAmericanController::class,'index'])->name('symposium_n_a.index');



});
